@@ -1,5 +1,5 @@
 #!/bin/bash
-sudo dpkg-buildpackage
+sudo dpkg-buildpackage || exit 1
 DEB=$(ls ../asterisk-phonepatch*deb | sort | tail -n1)
 rsync -avzP $DEB root@peru: || exit 1
 ssh root@peru "yes n | dpkg -i $(basename $DEB)" || exit 1
